@@ -32,6 +32,9 @@ extern struct size r_size;
 void SDLPRE_RefreshScale();
 void PDL_PumpEvents();
 void PDL_NotifyFocus(SDL_bool focus);
+
+void X11_Init();
+void X11_SetDoNotDisturb(SDL_bool set);
 #pragma GCC visibility pop
 
 #endif
