@@ -27,7 +27,7 @@ static int gles_init()
 	if (!gles_inited) {
 		int res = SDL_GLES_Init(desired_version);
 		if (res != 0) return res;
-		TRACE("SDL_GLES initialized (res=%d)\n", res);
+		TRACE("SDL_GLES initialized (res=%d)", res);
 		gles_inited = SDL_TRUE;
 
 		/* Palm SDL has a 16 bit depth buffer by default,
@@ -75,9 +75,14 @@ static void p_scale(struct point *p)
 {
 	const int ox = p->x, oy = p->y;
 	switch (s_rotate) {
+		case PDL_ORIENTATION_0:
+			p->x = ox * s_scale.x;
+			p->y = oy * s_scale.y;
+			break;
 		case PDL_ORIENTATION_270:
 			p->x = r_size.w - oy * s_scale.x;
 			p->y = ox * s_scale.y;
+			break;
 		default:
 			break;
 	}
@@ -87,9 +92,14 @@ static void p_unscale(struct point *p)
 {
 	const int ox = p->x, oy = p->y;
 	switch (s_rotate) {
+		case PDL_ORIENTATION_0:
+			p->x = ox / s_scale.x;
+			p->y = oy / s_scale.y;
+			break;
 		case PDL_ORIENTATION_270:
 			p->y = ox / s_scale.x;
 			p->x = v_size.w - oy / s_scale.y;
+			break;
 		default:
 			break;
 	}
@@ -102,7 +112,7 @@ static int filter_active_event(const SDL_ActiveEvent *event) {
 	fake->gain = event->gain;
 	fake->state = 0;
 	if (event->state & SDL_APPINPUTFOCUS) {
-		TRACE("Sending %s focus event\n", fake->gain ? "gain" : "lose");
+		TRACE("Sending %s focus event", fake->gain ? "gain" : "lose");
 		PDL_NotifyFocus(fake->gain);
 		fake->state = SDL_APPACTIVE;
 	}
@@ -142,7 +152,7 @@ static int filter_event(const SDL_Event *event)
 {
 	switch (event->type) {
 	case SDL_VIDEORESIZE:
-		TRACE("Deleted a video resize event\n");
+		TRACE("Deleted a video resize event");
 		return 0;
 	case SDL_ACTIVEEVENT:
 		return filter_active_event(&event->active);
@@ -157,23 +167,16 @@ static int filter_event(const SDL_Event *event)
 
 void SDLPRE_RefreshScale()
 {
-	switch (v_orient) {
-		case PDL_ORIENTATION_270:
-			s_rotate = PDL_ORIENTATION_270;
-			s_scale.x = (float)r_size.w / v_size.h;
-			s_scale.y = (float)r_size.h / v_size.w;
-			TRACE("Going for a 270 deg rotation\n");
-		break;
-		default:
-			TRACE("This orientation is not handled yet\n");
-		break;
-	}
+	/* Seems _everything_ is -90 deg rotated */
+	s_rotate = PDL_ORIENTATION_270;
+	s_scale.x = (float)r_size.w / v_size.h;
+	s_scale.y = (float)r_size.h / v_size.w;
 }
 
 int SDL_Init(Uint32 flags)
 {
 	OVERRIDES(SDL_Init, (Uint32 flags), int);
-	TRACE("called sdl_init with flags = 0x%x\n", flags);
+	TRACE("called sdl_init with flags = 0x%x", flags);
 
 	flags |= SDL_INIT_TIMER; /* We always want timers. */
 	flags &= ~SDL_INIT_JOYSTICK; /* We override it. */
@@ -184,6 +187,9 @@ int SDL_Init(Uint32 flags)
 		/* Success, hook some stuff. */
 		SDL_ShowCursor(SDL_DISABLE); /* Pre disables cursor by default. */
 		SDL_SetEventFilter(&filter_event);
+		if (flags & SDL_INIT_VIDEO) {
+			X11_Init();
+		}
 	}
 
 	return res;
@@ -192,7 +198,7 @@ int SDL_Init(Uint32 flags)
 void SDL_Quit()
 {
 	OVERRIDES(SDL_Quit, (), void);
-	TRACE("called sdl_quit\n");
+	TRACE("Called SDL_Quit");
 	gles_quit();
 	SUPER();
 }
@@ -202,7 +208,7 @@ int SDL_GL_SetAttribute(SDL_GLattr attr, int value)
 	gles_init();
 	switch (attr) {
 		case SDL_GL_CONTEXT_MAJOR_VERSION:
-			TRACE("Requested GL major version %d\n", value);
+			TRACE("Requested GL major version %d", value);
 			switch (value) {
 				case 1:
 					desired_version = SDL_GLES_VERSION_1_1;
@@ -211,19 +217,31 @@ int SDL_GL_SetAttribute(SDL_GLattr attr, int value)
 					desired_version = SDL_GLES_VERSION_2_0;
 					return 0;
 				default:
-					SDL_SetError("Invalid GLES major version: %d\n", value);
+					SDL_SetError("Invalid GLES major version: %d", value);
 					return -1;
 			}
 			break;
 		case SDL_GL_CONTEXT_MINOR_VERSION:
-			TRACE("Requested GL minor version %d\n", value);
+			TRACE("Requested GL minor version %d (ignored)", value);
+			return 0;
+		case SDL_GL_RED_SIZE:
+		case SDL_GL_GREEN_SIZE:
+		case SDL_GL_BLUE_SIZE:
+		case SDL_GL_ALPHA_SIZE:
+			TRACE("Ignoring color buffer size");
+			/* It does not work on the N900 either way. */
+			/* TODO: But we need support for 24bpp surfaces. */
+			return 0;
+		case SDL_GL_DOUBLEBUFFER:
+			TRACE("Ignoring doublebuffer preference");
+			/* I wouldn't know how to handle it either way. */
 			return 0;
 		case SDL_GL_DEPTH_SIZE:
-			TRACE("Requested depth buffer size %d\n", value);
+			TRACE("Requested depth buffer size %d", value);
 			SDL_GLES_SetAttribute(SDL_GLES_DEPTH_SIZE, value);
 			return 0;
 		default:
-			WARN("Application asks for unknown GL attribute %u, value %d\n", attr, value);
+			WARN("Application asks for unknown GL attribute %u, value %d", attr, value);
 			return 0;
 	}
 }
@@ -231,9 +249,13 @@ int SDL_GL_SetAttribute(SDL_GLattr attr, int value)
 SDL_Surface * SDL_SetVideoMode(int width, int height, int bpp, Uint32 flags)
 {
 	OVERRIDES(SDL_SetVideoMode, (int width, int height, int bpp, Uint32 flags), SDL_Surface*);
-	TRACE("Called SetVideoMode(%d, %d, %d, 0x%x)\n", width, height, bpp, flags);
+	TRACE("Called SetVideoMode(%d, %d, %d, 0x%x)", width, height, bpp, flags);
+	if (width == 0 && height == 0) {
+		width = r_size.w;
+		height = r_size.h;
+	}
 	if (flags & SDL_OPENGL) {
-		TRACE("Requested OpenGL video mode\n");
+		TRACE("Requested OpenGL video mode");
 		flags &= ~SDL_OPENGL; /* Our platform SDL doesn't handle it. */
 
 		int res = gles_init();
@@ -267,6 +289,16 @@ SDL_Surface * SDL_SetVideoMode(int width, int height, int bpp, Uint32 flags)
 	}
 }
 
+int SDL_VideoModeOK(int width, int height, int bpp, Uint32 flags)
+{
+	OVERRIDES(SDL_VideoModeOK, (int width, int height, int bpp, Uint32 flags), int);
+	TRACE("Asked if video mode %dx%dx%d (0x%x) is ok",
+		width, height, bpp, flags);
+	flags &= ~SDL_OPENGL;
+	int res = SUPER(width, height, bpp, flags);
+	return res;
+}
+
 void SDL_GL_SwapBuffers(void)
 {
 	SDL_GLES_SwapBuffers();
@@ -276,7 +308,7 @@ void SDL_SetEventFilter(SDL_EventFilter filter)
 {
 	OVERRIDES(SDL_SetEventFilter, (SDL_EventFilter filter), void);
 	if (filter != &filter_event) {
-		WARN("This application uses SetEventFilter, which is not implemented.\n");
+		WARN("This application uses SetEventFilter, which is not implemented.");
 	}
 	SUPER(filter);
 }
@@ -299,7 +331,7 @@ int SDL_UpperBlit(SDL_Surface *src, SDL_Rect *srcrect,
 {
 	OVERRIDES(SDL_UpperBlit, (SDL_Surface *src, SDL_Rect *srcrect, SDL_Surface *dst, SDL_Rect *dstrect), int);
 	if (dst == screen || src == screen) {
-		WARN("Someone is trying to blit from/to screen; this breaks the fourth wall\n");
+		WARN("Someone is trying to blit from/to screen; this breaks the fourth wall");
 	}
 	return SUPER(src, srcrect, dst, dstrect);
 }
